components Package
==================

:mod:`components` Package
-------------------------

.. automodule:: landlab.components
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`diff_2d` Module
---------------------

.. automodule:: landlab.components.diff_2d
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sample` Module
--------------------

.. automodule:: landlab.components.sample
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    landlab.components.craters
    landlab.components.dem_support
    landlab.components.diffusion
    landlab.components.fire_generator
    landlab.components.flexure
    landlab.components.flow_accum
    landlab.components.flow_routing
    landlab.components.fracture_grid
    landlab.components.nonlinear_diffusion
    landlab.components.overland_flow
    landlab.components.radiation
    landlab.components.sed_trp_shallow_flow
    landlab.components.simple_power_law_incision
    landlab.components.stream_power
    landlab.components.uniform_precip

